<?php
/*
 * e107 website system
 *
 * Copyright (C) 2008-2017 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 */

if (!defined('e107_INIT')) { exit; }

e107::includeLan(e_PLUGIN.'survey/languages/'.e_LANGUAGE.'.php');
e107::includeLan(e_LANGUAGEDIR.e_LANGUAGE.'/admin/lan_admin.php');
define('SURVEYCLASS', TRUE);
define('SURVEY_MODE_COOKIE', 0);
define('SURVEY_MODE_IP', 1);
define('SURVEY_MODE_USERID', 2);

class survey
{
	var $surveyRow;
	var $surveymode;
	var $barl = null;
	var $barr = null;
	var $bar = null;


	function __construct()
	{
		$this->barl = (file_exists(THEME.'images/barl.png') ? THEME_ABS.'images/barl.png' : e_PLUGIN_ABS.'survey/images/barl.png');
		$this->barr = (file_exists(THEME.'images/barr.png') ? THEME_ABS.'images/barr.png' : e_PLUGIN_ABS.'survey/images/barr.png');
		$this->bar = (file_exists(THEME.'images/bar.png') ? THEME_ABS.'images/bar.png' : e_PLUGIN_ABS.'survey/images/bar.png');	
	}


	/*
	function remove_survey_cookies
	Remove unused survey cookies. See: http://krijnhoetmer.nl/stuff/javascript/maximum-cookies/ Thanks Fanat1k - bugtracker #4983
	no parameters
	*/	
	function remove_survey_cookies()
	{ 
		$arr_surveys_cookies = array();
		if(!empty($_COOKIE))
		{
			foreach($_COOKIE as $cookie_name => $cookie_val)
			{	// Collect survey cookies

				if(substr($cookie_name,0,5) == 'survey_')
				{
					// e107::getDebug()->log("Survey: ".$cookie_name);
					list($str, $int) = explode('_', $cookie_name, 2);
					if (($str == 'survey') && is_numeric($int))
					{	// Yes, its survey's cookie
						$arr_surveys_cookies[] = $int;
					}
				}
			}
		}

		if (count($arr_surveys_cookies) > 1) 
		{	// Remove all except first (assumption: there is always only one active survey)
			rsort($arr_surveys_cookies);
			for($i = 1; $i < count($arr_surveys_cookies); $i++)
			{
				cookie("survey_{$arr_surveys_cookies[$i]}", "", (time() - 2592000));
			}
		}
	}	
	
	/*
	function delete_survey
	parameter in: $existing - existing survey id to be deleted
	parameter out: language text string on succesful delete, nothing on failed deletion
	*/
	function delete_survey($existing)
	{
		global $admin_log;
		$sql = e107::getDb();
		
		if ($sql->delete("surveys", " survey_id='".intval($existing)."' "))
		{
			if (function_exists("admin_purge_related"))
			{
				admin_purge_related("survey", $existing);
			}
			e107::getLog()->add('SURVEY_01',POLLAN_3.': '.LAN_DELETED.': '.$existing,'');
			//return POLL_ADLAN08;
		}
	}



	/* 
	function clean_survey_array
	parameter in: original array with survey answers as entered in the forums
	parameter out: cleaned array which trims the survey answers (to avoid 'falsely' empty answers) but allows to have '0' as an option

	Note: Used instead of array_filter because array_filter($array, 'trim') would also ignore the value '0' (as that returns FALSE)
	http://www.bubjavier.com/common-problems-php-arrayfilter-no-callback
	*/

	function clean_survey_array($val) 
	{
 		$val = trim($val); // trims the array to remove survey answers which are (seemingly) empty but which may contain spaces
  		$allowed_vals = array("0"); // Allows for '0' to be a survey answer option. Possible to add more allowed values. 
 		
 		return in_array($val, $allowed_vals, true) ? true : ( $val ? true : false );
	}

	/*
	function submit_survey
	$mode = 1 :: survey is main survey
	$mode = 2 :: survey is forum survey
	returns message
	*/
	function submit_survey($mode=1)
	{
		global $admin_log;
				
		$tp = e107::getParser();
		$sql = e107::getDb();
		
		$survey_title		= $tp->toDB($_POST['survey_title']);
		$survey_comment	= $tp->toDB($_POST['survey_comment']);
		$multipleChoice	= intval($_POST['multipleChoice']);
		$showResults	= intval($_POST['showResults']);
		$surveyUserclass	= intval($_POST['surveyUserclass']);
		$storageMethod	= intval($_POST['storageMethod']);
		$active_start	= (!$_POST['startmonth'] || !$_POST['startday'] || !$_POST['startyear'] ? 0 : mktime (0, 0, 0, $_POST['startmonth'], $_POST['startday'], $_POST['startyear']));
		$active_end		= (!$_POST['endmonth'] || !$_POST['endday'] || !$_POST['endyear'] ? 0 : mktime (0, 0, 0, $_POST['endmonth'], $_POST['endday'], $_POST['endyear']));
		$survey_options	= '';

		$surveyOption = $tp->filter($_POST['survey_option']);
		$surveyOption = array_filter($surveyOption, 'survey::clean_survey_array');
 
		foreach ($surveyOption as $key => $value)
		{
			$survey_options .= $tp->toDB($value).chr(1);
		}

		if (SURVEYACTION == 'edit' || vartrue($_POST['survey_id']))
		{
			$sql->update("surveys", "survey_title='{$survey_title}', 
			  				   survey_options='{$survey_options}', 
							   survey_comment='{$survey_comment}', 
							   survey_type={$mode},
							   survey_allow_multiple={$multipleChoice}, 
							   survey_result_type={$showResults}, 
							   survey_vote_userclass={$surveyUserclass}, 
							   survey_storage_method={$storageMethod}
							   WHERE survey_id=".intval(SURVEYID));

			/* update survey results - bugtracker #1124 .... */
			$sql->select("surveys", "survey_votes", "survey_id='".intval(SURVEYID)."' ");
			$foo = $sql->fetch();
			$voteA = explode(chr(1), $foo['survey_votes']);

			$survey_option = varset($survey_option, 0);
			$opt = count($survey_option) - count($voteA);

			if ($opt)
			{
				for($a=0; $a<=$opt; $a++)
				{
					$foo['survey_votes'] .= '0'.chr(1);
				}
				$sql->update("surveys", "survey_votes='".$foo['survey_votes']."' WHERE survey_id='".intval(SURVEYID)."' ");
			}

			e107::getLog()->add('SURVEY_02','ID: '.SURVEYID.' - '.$survey_title,'');
			//$message = POLLAN_45;
		} 
		else 
		{
			$votes = '';
			for($a=1; $a<=count($_POST['survey_option']); $a++)
			{
				$votes .= '0'.chr(1);
			}

			if ($mode == 1)
			{
				/* deactivate other surveys */
				if ($sql->select("surveys", "*", "survey_type=1 AND survey_vote_userclass!=255"))
				{
					$deacArray = $sql->db_getList();
					foreach ($deacArray as $deacsurvey)
					{
						$sql->update("surveys", "survey_end_datestamp='".time()."', survey_vote_userclass='255' WHERE survey_id=".$deacsurvey['survey_id']);
					}
				}
				$ret = $sql->insert("surveys", "'0', ".time().", ".intval($active_start).", ".intval($active_end).", ".ADMINID.", '{$survey_title}', '{$survey_options}', '{$votes}', '', '1', '".$tp->toDB($survey_comment)."', '".intval($multipleChoice)."', '".intval($showResults)."', '".intval($surveyUserclass)."', '".intval($storageMethod)."'");
				e107::getLog()->add('SURVEY_03','ID: '.$ret.' - '.$survey_title,'');		// Intentionally only log admin-entered surveys
			}
			else
			{
				$sql->insert("surveys", "'0', ".intval($_POST['iid']).", '0', '0', ".USERID.", '$survey_title', '$survey_options', '$votes', '', '2', '0', '".intval($multipleChoice)."', '0', '0', '".intval($storageMethod)."'");
			}
		}
		return varset($message);
	}

	function get_survey($query)
	{
		global $e107;		
		$sql = e107::getDb();
		
		if ($sql->gen($query))
		{
			$surveyArray = $sql->fetch();
			if (!check_class($surveyArray['survey_vote_userclass']))
			{
				$SURVEYMODE = 'disallowed';
			}
			else
			{
				switch($surveyArray['survey_storage_method'])
				{
					case SURVEY_MODE_COOKIE:
						$userid = '';
						$cookiename = 'survey_'.$surveyArray['survey_id'];
						if (isset($_COOKIE[$cookiename]))
						{
							$SURVEYMODE = 'voted';
						}
						else
						{
							$SURVEYMODE = 'notvoted';
						}
					break;

					case SURVEY_MODE_IP:
						$userid = e107::getIPHandler()->getIP(FALSE);
						$voted_ids = explode('^', substr($surveyArray['survey_ip'], 0, -1));
						if (in_array($userid, $voted_ids))
						{
							$SURVEYMODE = 'voted';
						}
						else
						{
							$SURVEYMODE = 'notvoted';
						}
					break;

					case SURVEY_MODE_USERID:
						if (!USER)
						{
							$SURVEYMODE = 'disallowed';
						}
						else
						{
							$userid = USERID;
							$voted_ids = explode('^', substr($surveyArray['survey_ip'], 0, -1));
							if (in_array($userid, $voted_ids))
							{
								$SURVEYMODE = 'voted';
							}
							else
							{
								$SURVEYMODE = 'notvoted';
							}
						}
					break;
				}
			}
		}
		else
		{
			return FALSE;
		}
		if (isset($_POST['surveyvote']) && isset($SURVEYMODE) && $SURVEYMODE == 'notvoted' && ($SURVEYMODE != 'disallowed'))
		{
			if ($_POST['votea'])
			{
//					$sql -> db_Select("surveys", "*", "survey_vote_userclass!=255 AND survey_type=1 ORDER BY survey_datestamp DESC LIMIT 0,1");
				$row = $surveyArray;
				extract($row);
				$survey_votes = varset($survey_votes);
				$votes = explode(chr(1), $survey_votes);
				if (is_array($_POST['votea']))
				{
					/* multiple choice vote */
					foreach ($_POST['votea'] as $vote)
					{
						$vote = intval($vote);
						$votes[($vote-1)] ++;
					}
				}
				else
				{
					$votes[($_POST['votea']-1)] ++;
				}
				$optionArray = explode(chr(1), $surveyArray['survey_options']);
				$optionArray = array_slice($optionArray, 0, -1);
				foreach ($optionArray as $k=>$v)
				{
					if (!$votes[$k])
					{
						$votes[$k] = 0;
					}
				}
				$votep = implode(chr(1), $votes);
				$surveyArray['survey_votes'] = $votep;
				$survey_ip = varset($survey_ip) . varset($userid);
				$sql->update("surveys", "survey_votes = '$votep'".($surveyArray['survey_storage_method'] != SURVEY_MODE_COOKIE ? ", survey_ip='".$survey_ip."^'" : '')." WHERE survey_id=".varset($survey_id));
				/*echo "
				<script type='text/javascript'>
				<!--
				setcook({$survey_id});
				//-->
				</script>
				";
				*/
				$survey_cookie_expire = time() + (3600 * 24 * 356 * 15); // FIXME cannot be used after 2023 (this year is the maxium unixstamp on 32 bit system)
			 	cookie('survey_'.$survey_id.'', $survey_id, $survey_cookie_expire);
				$SURVEYMODE = 'voted';
			}
		}
		$this->surveyRow = $surveyArray;
		$this->surveymode = varset($SURVEYMODE);
	}








	function render_survey($surveyArray = "", $type = "menu", $SURVEYMODE = "", $returnMethod=FALSE)
	{
		$ns = e107::getRender();
		$tp = e107::getParser();
		$sql = e107::getDb();

		$sc = e107::getScBatch('survey');

		global $SURVEYSTYLE;

		if ($type == 'preview')
		{
			$SURVEYMODE = 'notvoted';
			$sc->surveyType = $type;
		}
		elseif ($type == 'forum')
		{
			$sc->surveyPreview = true;
		}
		
		switch ($SURVEYMODE)
		{
			case 'query' :	// Show poll, register any vote

				if ($this->get_survey($surveyArray) === FALSE)
				{
					return '';		// No display if no survey
				}
				$surveyArray = $this->surveyRow;
				$SURVEYMODE = $this->surveymode;
				break;

			case 'results' :
				if ($sql->gen($surveyArray))
				{
					$surveyArray = $sql->fetch();
				}
				break;

			case 'oldsurveys':
				$SURVEYMODE = 'results';
			break;

			case 'notvoted':
				break;

			default:
			if(ADMIN)
			{
				return "<div class='alert alert-danger'>No \$SURVEYMODE set</div>";
			}

		}

		

		if ($type == 'preview')
		{
			$optionArray = array_filter($surveyArray['survey_option']);
			$voteArray = array();
			$voteArray = array_pad($voteArray, count($optionArray), 0);
			$surveyArray['survey_allow_multiple'] = $surveyArray['multipleChoice'];
		}
		else if ($type == 'forum')
		{
			if (isset($_POST['fpreview']))
			{
				$surveyArray['survey_allow_multiple'] = $surveyArray['multipleChoice'];
				$optionArray = $surveyArray['survey_option'];
			}
			else
			{
				$optionArray = explode(chr(1), $surveyArray['survey_options']);
				$optionArray = array_slice($optionArray, 0, -1);
			}
			$voteArray = explode(chr(1), $surveyArray['survey_votes']);
//			$voteArray = array_slice($voteArray, 0, -1);
		}
		else
		{  // Get existing results
			$optionArray = explode(chr(1), $surveyArray['survey_options']);
			$optionArray = array_slice($optionArray, 0, -1);
			$voteArray = explode(chr(1), $surveyArray['survey_votes']);
//			$voteArray = array_slice($voteArray, 0, -1);
		}

		$voteTotal = intval(array_sum($voteArray));
		$percentage = array();

		if (count($voteArray))
		{
			foreach ($voteArray as $votes)
			{
				$votes = intval($votes);

				if ($voteTotal > 0)
				{
					$percentage[] = round(($votes/$voteTotal) * 100, 2);
				}
				else
				{
					$percentage[] = 0;
				}
			}
		}




		$template = array();

		if(deftrue('BOOTSTRAP'))
		{
			$template = ($type == 'forum') ? e107::getTemplate('forum','forum_survey') : e107::getTemplate('survey');
		}
		else
		{
				/* get template */
			if (file_exists(THEME.'survey_template.php'))
			{
				require(THEME.'survey_template.php');
			}
			else if (!isset($SURVEY_NOTVOTED_START))
			{
			    require(e_PLUGIN.'survey/templates/survey_template.php');
			}

			$template['form']['start'] = $SURVEY_NOTVOTED_START ;
			$template['form']['item'] = $SURVEY_NOTVOTED_LOOP;
			$template['form']['end'] = 	$SURVEY_NOTVOTED_END;
			$template['results']['start'] = $SURVEY_VOTED_START;
			$template['results']['item'] = $SURVEY_VOTED_LOOP;
			$template['results']['end'] = $SURVEY_VOTED_END;
			$template['denied']['start'] = $SURVEY_DISALLOWED_START;
			$template['denied']['item'] = $SURVEY_DISALLOWED_LOOP ;
			$template['denied']['end'] = $SURVEY_DISALLOWED_END ;
		}


		$sc->setVars($surveyArray);

		if ($surveyArray['survey_comment']) // Only get comments if they're allowed on survey. And we only need the count ATM
		{
			$sc->surveyCommentTotal = $sql->count("comments", "(*)", "WHERE `comment_item_id`='".intval($surveyArray['survey_id'])."' AND `comment_type`=4");
		}

		$sc->surveyCount 	    = $sql->count("surveys", "(*)", "WHERE survey_id <= '".$surveyArray['survey_id']."'");
		$sc->surveyRenderMode = $type;
		$sc->surveyVoteTotal  = $voteTotal;
		$sc->surveyRenderType = $type;





		$text = '';

		switch ($SURVEYMODE)
		{

			case 'notvoted':

				$text = "<form method='post' action='".e_SELF.(e_QUERY ? "?".e_QUERY : "")."'>\n";
				$text .= $tp->parseTemplate($template['form']['start'],true, $sc);
				$count = 1;
				$sc->answerCount = 1;

				foreach ($optionArray as $option)
				{
					$sc->answerOption = $option; 
					$text .= $tp->parseTemplate($template['form']['item'], true, $sc);
						
					$count ++;
					$sc->answerCount++;
				}
				
				$text .= $tp->parseTemplate($template['form']['end'], true, $sc);

				$text .= "</form>";
				break;





			case 'voted':
			case 'results' :

				if ($surveyArray['survey_result_type'] && !strstr(e_SELF, "comment.php"))
				{
					$text = "<div style='text-align: center;'><br /><br />".LAN_THANK_YOU."<br /><br /><a href='".e_HTTP."comment.php?comment.survey.".$surveyArray['survey_id']."'>".POLLAN_40."</a></div><br /><br />";
				}
				else
				{

					$text = $tp->parseTemplate( $template['results']['start'], true, $sc);
					$count = 0;
					$sc->answerCount = 0;

					foreach ($optionArray as $option)
					{
						$sc->surveyPercentage = $percentage[$count];
						$sc->answerOption   = $option;
						$sc->surveyVotes      = $voteArray[$count];

						$text .= $tp->parseTemplate($template['results']['item'], true, $sc);

						$count ++;
						$sc->answerCount++;
					}
						
					$text .= $tp->parseTemplate($template['results']['end'], true, $sc);
				}
			
				break;





			case 'disallowed':

				$text = $tp->parseTemplate($template['denied']['start'], true, $sc);
				$count = 0;

				foreach ($optionArray as $option)
				{
					$sc->surveyPercentage = $percentage[$count];
					$sc->answerOption   = $option;
					$sc->surveyVotes      = $voteArray[$count];

					$text .= $tp->parseTemplate($template['denied']['item'], true, $sc);
					$count ++;
				}

				$text .= $tp->parseTemplate($template['denied']['end'], true, $sc);

				break;
		}


		if (!defined("SURVEYRENDERED")) define("SURVEYRENDERED", TRUE);
		
		$caption = (file_exists(THEME."images/survey_menu.png") ? "<img src='".THEME_ABS."images/survey_menu.png' alt='' /> ".LAN_PLUGIN_SURVEY_NAME : LAN_PLUGIN_SURVEY_NAME);
		
		if ($type == 'preview')
		{
			$caption = LAN_CREATE.SEP.LAN_PREVIEW; // "Preview"; // TODO not sure this is used. 
			$text = "<div class='clearfix'>\n<div class='well span3'>".$text."</div></div>";
		}
		elseif ($type == 'forum')
		{
			$caption = LAN_4;
		}

		if ($returnMethod)
		{
			return $text;
		}
		else
		{
			$ns->tablerender($caption, $text, 'survey');
		}
	}


	
	function generateBar($perc)
	{
		if(deftrue('BOOTSTRAP',false))
		{
			$val = intval($perc);
			 return '
			 <div class="progress">
			 <div class="bar progress-bar" role="progressbar" aria-valuenow="'.$val.'" aria-valuemin="0" aria-valuemax="100" style="width: '.$val.'%;">
			   <span class="sr-only">'.$val.'%</span>
			 </div>
			 </div>';	
			
		}
		else
		{
			$barl = $this->barl;
			$barr = $this->barr;
			$bar = $this->bar;
			return ($perc ? "<div style='width: 100%'><div style='background-image: url($barl); width: 5px; height: 14px; float: left;'></div><div style='background-image: url($bar); width: ".min(intval($perc), 90)."%; height: 14px; float: left;'></div><div style='background-image: url($barr); width: 5px; height: 14px; float: left;'></div></div>" : "");	
		}	
	}





	/*
	function renderSurveyForm
	$mode = "admin" :: called from admin_config.php
	$mode = "forum" :: called from forum_post.php
	*/	
	/**
	 * Render a Survey creation Form
	 * @param $mode string - admin | forum | front 
	 */
	function renderSurveyForm($mode='admin')
	{
		$tp = e107::getParser();
		$frm = e107::getForm();
	//	echo "MODE=".$mode;
		
		//XXX New v2.x default for front-end. Currently used by forum-post in bootstrap mode. 
		// TODO LAN - Needs a more generic LAN rewrite when used on another area than forum


		if ($mode == 'front')
		{				
			
			$text = "
			
			<div class='alert alert-info'>
				<small >".LAN_FORUM_3029."</small>
			</div>";


		//		$text .= "<form>";


			$text .= "

				<div class='form-group'>
					<label for='survey_title'>".POLLAN_3."</label>
					".$frm->text('survey_title', $tp->post_toForm(vartrue($_POST['survey_title'])), '200', array('placeholder' => POLLAN_3, 'id' => 'survey_title'))." 
				</div>";

			$option_count = vartrue($_POST['survey_option']) ? count($_POST['survey_option']) : 2;
			$text .= "		
				<div id='surveysection'>
					<label for='surveyopt'>".POLLAN_4."</label>";
				
				for($count = 1; $count <= $option_count; $count++)
				{
					// if ($count != 1 && $_POST['survey_option'][($count-1)] =="")
					// {
					// //	break;
					// }
					
					$opt = ($count==1) ? "id='survey_answer'" : "";

					$text .= "<div class='form-group' ".$opt.">
								".$frm->text('survey_option[]', $_POST['survey_option'][($count-1)], '200', array('placeholder' => POLLAN_4, 'id' => $opt))."
							  </div>";
				}

				$text .= "</div>"; // end surveysection div

				$text .= "<div  class='form-group control-group'>
							<input class='btn btn-default' type='button' id='saddoption' name='saddoption' value='".LAN_ADD_MORE."' />
						</div>

				";
			
			//FIXME - get this looking good with Bootstrap CSS only. 
			
			$opts = array(1 => LAN_YES, 0=> LAN_NO);
				
			// Set to IP address.. Can add a pref to Survey admin for 'default front-end storage method' if demand is there for it. 

		$text .= "<br />
			 <div class='form-horizontal control-group'>
				<label class='control-label'>".LAN_MULTIPLE_CHOICE."</label>
				<div class='radio controls'>
					". $frm->radio('multipleChoice',$opts, vartrue($_POST['multipleChoice'], 0) ).$frm->hidden('storageMethod', 1)."
				</div>
			</div>			
		";

	//	$text .= "</form>";
		
		return $text;
		
			
	/*
			$text .= "
				<div class='controls controls-row'>".POLL_506."
				
				<input type='radio' name='multi/pleChoice' value='1'".(vartrue($_POST['multipleChoice']) ? " checked='checked'" : "")." /> ".POLL_507."&nbsp;&nbsp;
				<input type='radio' name='multi/pleChoice' value='0'".(!$_POST['multipleChoice'] ? " checked='checked'" : "")." /> ".POLL_508."
				
				</div>";
			*/
		
			//XXX Should NOT be decided by USER 
			/*
			$text .= "

			<div>
			".POLLAN_16."
			
			<input type='radio' name='storageMethod' value='0'".(!vartrue($_POST['storageMethod']) ? " checked='checked'" : "")." /> ".POLLAN_17."<br />
			<input type='radio' name='storageMethod' value='1'".($_POST['storageMethod'] == 1 ? " checked='checked'" : "")." /> ".LAN_IP_ADDRESS."<br />
			<input type='radio' name='storageMethod' value='2'".($_POST['storageMethod'] ==2 ? " checked='checked'" : "")." /> ".POLLAN_19."
			</div>
			";
			*/
		
			
		}
		
		
		//TODO Hardcoded FORUM code needs to be moved somewhere. 
		if ($mode == 'forum') // legacy code.
		{
			$text = "
			<tr>
				<td class='forumheader3' colspan='2'><span class='smalltext'>".LAN_FORUM_3029."</span></td>
			</tr>
			<tr>
				<td class='forumheader3' style='width:20%'><div class='normaltext'>".POLLAN_3.": </div></td>
				<td class='forumheader3' style='width:80%' class='forumheader3'><input class='tbox' type='text' name='survey_title' size='70' value='".$tp->post_toForm(vartrue($_POST['survey_title']))."' maxlength='200' /></td>
			</tr>";

			$option_count = (count(vartrue($_POST['survey_option'])) ? count($_POST['survey_option']) : 1);
			$text .= "
			<tr>
				<td class='forumheader3' style='width:20%'>".POLLAN_4."</td>
				<td class='forumheader3' style='width:80%'>
				<div id='surveysection'>";

				for($count = 1; $count <= $option_count; $count++)
				{
					if ($count != 1 && $_POST['survey_option'][($count-1)] =="")
					{
						break;
					}

					$opt = ($count==1) ? "id='surveyopt'" : "";
					$text .="<span {$opt}><input  class='tbox' type='text' name='survey_option[]' size='40' value=\"".$_POST['survey_option'][($count-1)]."\" maxlength='200' />";
					$text .= "</span><br />";
				}

				$text .="
				</div>
				<input class='btn btn-default btn-secondary button' type='button' name='addoption' value='".LAN_ADD_MORE."' onclick=\"duplicateHTML('surveyopt','surveysection')\" /><br />
				</td>
			</tr>
			<tr>
				<td class='forumheader3' style='width:20%'>".LAN_MULTIPLE_CHOICE."</td>
				<td class='forumheader3' style='width:80%'>
				<input type='radio' name='multipleChoice' value='1'".(vartrue($_POST['multipleChoice']) ? " checked='checked'" : "")." /> ".LAN_YES."&nbsp;&nbsp;
				<input type='radio' name='multipleChoice' value='0'".(!$_POST['multipleChoice'] ? " checked='checked'" : "")." /> ".LAN_NO."
			</td>
			</tr>
			<tr>
				<td class='forumheader3'style='width:30%'>".POLLAN_16."</td>
				<td class='forumheader3'>
					<input type='radio' name='storageMethod' value='0'".(!vartrue($_POST['storageMethod']) ? " checked='checked'" : "")." /> ".POLLAN_17."<br />
					<input type='radio' name='storageMethod' value='1'".($_POST['storageMethod'] == 1 ? " checked='checked'" : "")." /> ".LAN_IP_ADDRESS."<br />
					<input type='radio' name='storageMethod' value='2'".($_POST['storageMethod'] ==2 ? " checked='checked'" : "")." /> ".POLLAN_19."
				</td>
			</tr>
			";


			return $text;
		}

		$formgo = e_SELF.(e_QUERY && !defined("RESET") && strpos(e_QUERY, 'delete') === FALSE ? "?".e_QUERY : "");

		$text = "<div>
		<form method='post' action='{$formgo}'>
		<table class='table adminform'>
        <colgroup>
			<col class='col-label' />
			<col class='col-control' />
		</colgroup>
		<tr>
		<td style='width:30%'><div class='normaltext'>".POLLAN_3.":</div></td>
		<td style='width:70%'>
		<input class='tbox input-xxlarge form-control' type='text' name='survey_title' size='70' value='".$tp->post_toForm(varset($_POST['survey_title']))."' maxlength='200' />";

		$option_count = (varset($_POST['survey_option']) && count($_POST['survey_option']) ? count($_POST['survey_option']) : 2);

		$text .= "</td></tr><tr>
		<td style='width:30%;vertical-align:top'>".LAN_OPTIONS." :</td>
		<td style='width:70%'>
		<div id='surveysection'>";

		for($count = 1; $count <= $option_count; $count++)
		{
			$opt = ($count==1) ? "id='surveyopt'" : "";
			$text .="<span class='form-inline' style='display:inline-block; padding-bottom:5px' {$opt}><input  class='tbox input-large form-control' type='text' name='survey_option[]' size='40' value=\"".$tp->post_toForm($_POST['survey_option'][($count-1)])."\" maxlength='200' />";
			$text .= "</span><br />";
		}

		$text .="</div><input class='btn btn-default' type='button' name='saddoption' value='".LAN_ADD_MORE."' onclick=\"duplicateHTML('surveyopt','surveysection')\" /><br />
		</td></tr>

		<tr>
		<td style='width:30%'>".LAN_MULTIPLE_CHOICE."</td>
		<td style='width:70%'>
		<input type='radio' name='multipleChoice' value='1'".(varset($_POST['multipleChoice']) ? " checked='checked'" : "")." /> ".LAN_YES."&nbsp;&nbsp;
		<input type='radio' name='multipleChoice' value='0'".(!varset($_POST['multipleChoice']) ? " checked='checked'" : "")." /> ".LAN_NO."
		</td>
		</tr>

		<tr>
		<td style='width:30%'>".POLLAN_12."</td>
		<td style='width:70%'>
		<input type='radio' name='showResults' value='0'".(!varset($_POST['showResults']) ? " checked='checked'" : "")." /> ".POLLAN_13."<br />
		<input type='radio' name='showResults' value='1'".(varset($_POST['showResults']) ? " checked='checked'" : "")." /> ".POLLAN_14."
		</td>
		</tr>

		<tr>
		<td style='width:30%'>".POLLAN_15."</td>";
		
		$uclass = (ADMIN) ? "" : "public,member,admin,classes,matchclass";
		
		
		$text .= "
		<td>".r_userclass("surveyUserclass", vartrue($_POST['surveyUserclass']), 'off', $uclass)."</td>
		</tr>

		<tr>
		<td style='width:30%'>".POLLAN_16."</td>
		<td>
		<input type='radio' name='storageMethod' value='0'".(!varset($_POST['storageMethod']) ? " checked='checked'" : "")." /> ".POLLAN_17."<br />
		<input type='radio' name='storageMethod' value='1'".(varset($_POST['storageMethod']) ==1 ? " checked='checked'" : "")." /> ".LAN_IP_ADDRESS."<br />
		<input type='radio' name='storageMethod' value='2'".(varset($_POST['storageMethod']) ==2 ? " checked='checked'" : "")." /> ".POLLAN_19."
		</td></tr>

		<tr>
		<td>".LAN_COMMENTS_ALLOWED.": </td><td>
		<input type='radio' name='survey_comment' value='1'".(varset($_POST['survey_comment']) ? " checked='checked'" : "")." /> ".LAN_YES."
		<input type='radio' name='survey_comment' value='0'".(!varset($_POST['survey_comment']) ? " checked='checked'" : "")." /> ".LAN_NO."
		</td>
		</tr>
		</table>
		<div class='buttons-bar center'>";

		if (isset($_POST['preview']) || varset($_POST['edit']))
		{
			// $text .= "<input  type='submit' name='preview' value='".LAN_PREVIEW."' /> ";
			$text .= $frm->admin_button('preview',LAN_PREVIEW,'other');
			
			if (SURVEYACTION == 'edit')
			{
				$text .= $frm->admin_button('submit', LAN_UPDATE, 'update')."
				
				<input type='hidden' name='survey_id' value='".intval($_POST['survey_id'])."' /> ";
			}
			else
			{
				$text .= $frm->admin_button('submit','no-value','submit', LAN_CREATE);
			//	$text .= "<input type='submit' name='submit' value='".POLLAN_23."' /> ";
			}
		} 
		else 
		{
			$text .= $frm->admin_button('preview','no-value','other',LAN_PREVIEW);
		//	$text .= "<input  type='submit' name='preview' value='".LAN_PREVIEW."' /> ";
		}
		
		if (defset('SURVEYID')) 
		{
			$text .= $frm->admin_button('reset','no-value','reset',LAN_CLEAR);
		//	$text .= "<input  type='submit' name='reset' value='".LAN_CLEAR."' /> ";
		}

		$text .= "</div>
		</form>
		</div>";

		return $text;
	}
}




class survey_shortcodes extends e_shortcode
{
	public $answerOption    = array();
	public $answerCount     = 0;
	public $surveyRenderType  = null; // type
	public $surveyRenderMode  = null;
	public $surveyPreview     = false;
	public $surveyVoteTotal   = 0;
	public $surveyCommentTotal = 0;
	public $surveyPercentage  = 0;
	public $surveyVotes       = 0;
	public $surveyCount       = 0; // total surveys in the system

	private $barl = null;
	private $barr = null;
	private $bar = null;

	public function __construct()
	{
		$this->barl = (file_exists(THEME.'images/barl.png') ? THEME_ABS.'images/barl.png' : e_PLUGIN_ABS.'survey/images/barl.png');
		$this->barr = (file_exists(THEME.'images/barr.png') ? THEME_ABS.'images/barr.png' : e_PLUGIN_ABS.'survey/images/barr.png');
		$this->bar = (file_exists(THEME.'images/bar.png') ? THEME_ABS.'images/bar.png' : e_PLUGIN_ABS.'survey/images/bar.png');
	}

	function sc_soption($parm='')
	{
		if(!empty($this->answerOption))
		{
			return $this->answerOption;
		}

	}


	function sc_spercentage($parm=null)
	{
		return $this->surveyPercentage."%";
	}


	function sc_sauthor($parm=null)
	{
		$uparams = array('id' => $this->var['survey_admin_id'], 'name' => $this->var['user_name']);
		$link = e107::getUrl()->create('user/profile/view', $uparams);
		$userlink = "<a href='".$link."'>".$this->var['user_name']."</a>";

	//	return print_a($this->var,true);
		return LAN_POSTED_BY." ".(($this->surveyType == 'preview' || $this->surveyType == 'forum') ? USERNAME : $userlink);
	}


	function sc_soldsurveys($parm=null)
	{
		// return 'type: '.$this->surveyCount;

		if (intval($this->surveyCount) > 1 && ($this->surveyRenderType == 'menu'))
		{
			return "<a href='".e_PLUGIN_ABS."survey/oldsurveys.php'>".POLLAN_28."</a>" ;
		}

	}


	function sc_sdisallowmessage($parm=null)
	{
		if ($this->var['survey_vote_userclass'] == 253)
		{
			return POLLAN_41;
		}
		elseif ($this->var['survey_vote_userclass'] == 254)
		{
			return POLLAN_42;
		}
		else
		{
			return POLLAN_43;
		}

	}


	function sc_svotes($parm=null)
	{
		return POLLAN_31.": ".$this->surveyVotes;
	}


	function sc_sbar($parm=null)
	{

		$perc = $this->surveyPercentage;

		if(deftrue('BOOTSTRAP',false))
		{

		//	return "<span class='label label-danger'>".$perc."</span>";
			$val = intval($perc);
			 return '
			 <div class="progress">
			 <div class="bar progress-bar" role="progressbar" aria-valuenow="'.$val.'" aria-valuemin="0" aria-valuemax="100" style="width: '.$val.'%;">
			   <span class="sr-only">'.$val.'%</span>
			 </div>
			 </div>';

		}
		else
		{
			$barl = $this->barl;
			$barr = $this->barr;
			$bar = $this->bar;
			return ($perc ? "<div style='width: 100%'><div style='background-image: url($barl); width: 5px; height: 14px; float: left;'></div><div style='background-image: url($bar); width: ".min(intval($perc), 90)."%; height: 14px; float: left;'></div><div style='background-image: url($barr); width: 5px; height: 14px; float: left;'></div></div>" : "");
		}
	}


	function sc_soptionbutton($parm='')
	{
		return ($this->var['survey_allow_multiple'] ? "<input type='checkbox' name='votea[]' value='$this->answerCount' />" : "<input type='radio' name='votea' value='".$this->answerCount."' />");
	}


	function sc_squestion($parm = "")
	{
		$tp = e107::getParser();
		return $tp->toHTML($this->var['survey_title'], true, "TITLE");
	}


	function sc_sanswer($parm='')
	{
		$frm = e107::getForm();
		$opt = array('label'=> $this->answerOption);

		if(empty($this->var['survey_allow_multiple']))
		{
			return $frm->radio('votea', $this->answerCount,false, $opt);
		}
		else
		{
			return $frm->checkbox('votea[]', $this->answerCount,false, $opt);
		}

	}


	function sc_ssubmitbutton($parm=null)
	{

		if (('preview' == $this->surveyType || $this->surveyPreview == true) && strpos(e_REQUEST_SELF, "forum") === false)
		{
			return "<input class='button btn btn-default btn-secondary e-tip' type='button' name='null' title='".LAN_SUBMIT."' value='".LAN_SUBMIT."' />";
		}

		return "<input class='button btn btn-primary' type='submit' name='surveyvote' value='".LAN_SUBMIT."' />";
				// disable submit when previewing the survey or when NOT viewing the survey in the forum
	}


	function sc_svote_total($parm=null)
	{

		return POLLAN_31.": ".intval($this->surveyVoteTotal);
	}


	function sc_scomments($parm=null)
	{
		return ($this->var['survey_comment'] ? " <a href='".e_HTTP."comment.php?comment.survey.".$this->var['survey_id']."'>".LAN_COMMENTS.": ".$this->surveyCommentTotal."</a>" : "");

	}
}



/*
e107::js('inline', '

	function setcook(surveyid){
		var name = "survey_"+surveyid;
		var date = new Date();
		var value = surveyid;
		date.setTime(date.getTime()+(365*24*60*60*1000));
		var expires = "; expires="+date.toGMTString();
		document.cookie = name+"="+value+expires+"; path=/";
	}
		');*/


?>
